import _objectSpread from '@babel/runtime/helpers/esm/objectSpread2';
import _objectWithoutProperties from '@babel/runtime/helpers/esm/objectWithoutProperties';
import 'react';
import PropTypes from 'prop-types';
import { useBrand, getLabel, overrideReconciler } from '@westpac/core';
import '@babel/runtime/helpers/defineProperty';
import { jsx } from '@emotion/react/jsx-runtime';

var _excluded$1 = ["state"];
(Label === null || Label === void 0 ? void 0 : Label.defaultProps) || {};

// ==============================
// Component
// ==============================

var Label$1 = function Label(_ref) {
  _ref.state;
    var rest = _objectWithoutProperties(_ref, _excluded$1);
  return jsx("span", _objectSpread({}, rest));
};

// ==============================
// Styles
// ==============================

var labelStyles = function labelStyles(_, _ref3) {
  var look = _ref3.look;
  var _useBrand = useBrand(),
    COLORS = _useBrand.COLORS,
    TYPE = _useBrand.TYPE;
  return _objectSpread(_objectSpread({
    label: getLabel('label'),
    display: 'inline-block',
    border: '1px solid',
    borderRadius: '0.125rem',
    fontSize: '0.75rem',
    lineHeight: 1,
    padding: '0.1875rem 0.375rem 0.125rem',
    textAlign: 'center',
    verticalAlign: 'baseline',
    whiteSpace: 'nowrap',
    color: look === 'faint' ? COLORS.muted : '#fff',
    backgroundColor: look === 'faint' ? '#fff' : COLORS[look],
    borderColor: look === 'faint' ? COLORS.border : COLORS[look]
  }, TYPE.bodyFont[400]), {}, {
    ':empty': {
      display: 'none'
    },
    '@media print': {
      color: '#000',
      backgroundColor: '#fff',
      border: '1px solid #000'
    }
  });
};

// ==============================
// Attributes
// ==============================

var labelAttributes = function labelAttributes() {
  return null;
};

// ==============================
// Exports
// ==============================

var defaultLabel = {
  component: Label$1,
  styles: labelStyles,
  attributes: labelAttributes
};

var pkg = {
	name: "@westpac/label",
	version: "2.2.0",
	description: "Small, coloured UI items used to highlight a word",
	homepage: "https://gel.westpacgroup.com.au/design-system",
	repository: "https://github.com/WestpacGEL/GEL/tree/master/components/label",
	license: "GPL-3.0+",
	author: "Westpac GEL Team <gel@westpac.com.au>",
	contributors: [
		{
			name: "Dominik Wilkowski",
			email: "Hi@Dominik-Wilkowski.com",
			url: "https://dominik-wilkowski.com"
		},
		{
			name: "Jonathan Stening",
			email: "info@jonathanstening.com",
			url: "http://jonathanstening.com"
		},
		{
			name: "Jeremy Ortiz",
			email: "jeremy@jeremyortiz.io",
			url: "https://www.jeremyortiz.io/"
		},
		{
			name: "Flore Laforge",
			email: "florelaforge@gmail.com",
			url: "http://florelaforge.com/"
		}
	],
	main: "dist/westpac-label.cjs.js",
	module: "dist/westpac-label.esm.js",
	scripts: {
		start: "PACKAGE_NAME=label NODE_ENV=development webpack server --config ../../helpers/example/start.webpack.config.js",
		test: "exit 0 # start-server-and-test start http://localhost:8080 test:all",
		"test:all": "yarn test:integration",
		"test:dev": "start-server-and-test start http://localhost:8080 test:test-dev",
		"test:integration": "cypress run",
		"test:test-dev": "cypress open"
	},
	dependencies: {
		"@babel/runtime": "^7.14.8",
		"@westpac/core": "^3.2.0",
		"prop-types": "^15.7.2"
	},
	devDependencies: {
		"@emotion/react": "^11.10.6",
		cypress: "^8.0.0",
		react: "^18.2.0",
		"start-server-and-test": "^1.12.6"
	},
	peerDependencies: {
		"@emotion/react": "^11.10.6",
		react: "^18.2.0"
	},
	blender: {
		recipe: "blender/recipe.js"
	},
	components: [
		{
			name: "Label",
			src: "Label.tsx"
		}
	]
};

var _excluded = ["look", "value", "overrides"];
// ==============================
// Component
// ==============================

var Label = function Label(_ref) {
  var _ref$look = _ref.look,
    look = _ref$look === void 0 ? 'primary' : _ref$look,
    value = _ref.value,
    componentOverrides = _ref.overrides,
    rest = _objectWithoutProperties(_ref, _excluded);
  var _useBrand = useBrand(),
    tokenOverrides = _useBrand.OVERRIDES[pkg.name],
    brandOverrides = _useBrand[pkg.name];
  var defaultOverrides = {
    Label: defaultLabel
  };
  var state = _objectSpread({
    look: look,
    value: value,
    overrides: componentOverrides
  }, rest);
  var _overrideReconciler = overrideReconciler(defaultOverrides, tokenOverrides, brandOverrides, componentOverrides),
    _overrideReconciler$L = _overrideReconciler.Label,
    Label = _overrideReconciler$L.component,
    labelStyles = _overrideReconciler$L.styles,
    labelAttributes = _overrideReconciler$L.attributes;
  return jsx(Label, _objectSpread(_objectSpread(_objectSpread({}, rest), {}, {
    state: state
  }, labelAttributes(state)), {}, {
    css: labelStyles(state),
    children: value
  }));
};
Label.propTypes = {
  // ----------------------------- Warning --------------------------------
  // | These PropTypes are generated from the TypeScript type definitions |
  // |     To update them edit TypeScript types and run "yarn prop-types"  |
  // ----------------------------------------------------------------------
  /**
   * Label look
   */
  look: PropTypes.oneOf(['danger', 'faint', 'hero', 'info', 'neutral', 'primary', 'success', 'warning']).isRequired,
  /**
   * The override API
   */
  overrides: PropTypes.shape({
    Label: PropTypes.shape({
      attributes: PropTypes.func,
      component: PropTypes.elementType,
      styles: PropTypes.func
    })
  }),
  /**
   * Label text
   */
  value: PropTypes.string.isRequired
};
Label.defaultProps = {
  look: 'primary'
};

export { Label };
